avatars.runner.Runner
=====================

.. currentmodule:: avatars.runner

.. autoclass:: Runner


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~Runner.__init__
      ~Runner.add_link
      ~Runner.add_table
      ~Runner.advise_parameters
      ~Runner.delete_link
      ~Runner.delete_parameters
      ~Runner.delete_table
      ~Runner.download_report
      ~Runner.from_yaml
      ~Runner.get_all_results
      ~Runner.get_job
      ~Runner.get_specific_result
      ~Runner.get_specific_result_urls
      ~Runner.get_status
      ~Runner.get_yaml
      ~Runner.kill
      ~Runner.print_parameters
      ~Runner.privacy_metrics
      ~Runner.projections
      ~Runner.render_plot
      ~Runner.run
      ~Runner.sensitive_unshuffled
      ~Runner.set_parameters
      ~Runner.shuffled
      ~Runner.signal_metrics
      ~Runner.update_parameters
      ~Runner.upload_file
